@@ -1,6 +1,6 @@
 package Audio::Nama::TrackWaveform;
 use Audio::Nama::Globals qw($project $config $gui %ti);
-use Modern::Perl '2020';
+use v5.36;
 our $VERSION = 1.0;
 use Role::Tiny;
 use Try::Tiny;
