@@ -4,10 +4,13 @@
 # well-defined interfaces
 
 package Audio::Nama::Util;
-use Modern::Perl '2020'; 
+use v5.36;
 our $VERSION = 1.0;
 use Carp;
 use Data::Dumper::Concise;
+use IO::Async::Timer::Periodic;
+use IO::Async::Timer::Countdown;
+use IO::Async::Loop;
 use Audio::Nama::Assign qw(json_out);
 use Audio::Nama::Globals qw(:all);
 use Audio::Nama::Log qw(logit logsub logpkg);
@@ -48,6 +51,10 @@ our %EXPORT_TAGS = ( 'all' => [ qw(
 	dumper
 	route_output_channels
 
+	timer
+	start_event
+	stop_event
+
 ) ] );
 
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
@@ -255,5 +262,49 @@ sub route_output_channels {
 	@route;
 }
 
+my @events = qw(
+	poll_engine
+	update_playback_position_display
+	wraparound
+	processing_time
+	remote_control
+	jack_polling
+	command_output
+);
+my %events = map{ $_ => 1} @events;
+sub check_event_type ($type) {
+	confess "illegal event type: $type"
+	unless $events{$type}
+}
+
+sub timer ($delay, $interval, $coderef ) {
+	my $timer;
+	if ($interval == 0){
+		$timer = IO::Async::Timer::Countdown->new(
+			delay => $delay,
+			on_expire => $coderef, 
+		);
+	}
+	else {
+		$timer = IO::Async::Timer::Periodic->new(
+			interval => $interval,
+			on_tick => $coderef,
+		);
+	}
+	$timer->start;
+	$text->{loop}->add($timer);
+	$timer
+}
+sub stop_event ($label) {
+	check_event_type($label);
+	my $event = $Audio::Nama::project->{events}->{$label};
+	$event->stop if defined $event 
+}
+sub start_event ($label, $async) {
+	check_event_type($label);
+	$Audio::Nama::project->{events}->{$label} = $async
+}
+
+
 1;
 __END__
\ No newline at end of file
