@@ -20,18 +20,8 @@ sub wav_format{
 	my $track = shift;
 	Audio::Nama::wav_format($track->full_path)
 }
-sub wav_width {
-	my $track = shift;
-	no warnings 'uninitialized';
- 	my ($depth,$width,$freq) = split ',', $track->wav_format;
-	$width
-}
-sub wav_frequency {
-	my $track = shift;
-	no warnings 'uninitialized';
- 	my ($depth,$width,$freq) = split ',', $track->wav_format;
-	$freq
-}
+
+	
 sub dir {
 	my $self = shift;
 	 $self->project  
@@ -58,7 +48,7 @@ sub current_wav {
 	my $last = $track->current_version;
 	if 	($track->rec){ 
 		$track->name . '_' . $last . '.wav'
-	} elsif ( $track->rw ne MON){ 
+	} elsif ( $track->rw eq PLAY){ 
 		my $filename = $track->targets->{ $track->playback_version } ;
 		$filename
 	} else {
@@ -72,14 +62,14 @@ sub current_version {
 
 	# two possible version numbers, depending on REC/PLAY status
 	
-	if 	($track->{rw} eq REC)
+	if 	($track->rec)
 	{ 
 		my $last = $config->{use_group_numbering} 
 					? Audio::Nama::Bus::overall_last()
 					: $track->last;
 		return ++$last
 	}
-	elsif ($track->{rw} ne MON){ return $track->playback_version } 
+	elsif ($track->play){ return $track->playback_version } 
 	else { return 0 }
 }
 
